pub mod m1 {
    pub fn f1() -> i32 {
        println!("edderocks1111111111111111");
        111
    }

    pub fn f2() -> i32 {
        println!("edderocks222222222222222222222222");
        222
    }
}

pub fn f3() -> i32 {
    println!("fffffffffffffffffff333333333333333333333333");
    333
}
